var NAVTREEINDEX0 =
{
"Poisson_surface_reconstruction_3_2poisson_reconstruction_example_8cpp-example.html":[5,29],
"Polygon_mesh_processing_2acvd_remeshing_example_8cpp-example.html":[5,50],
"Polygon_mesh_processing_2cc_compatible_orientations_8cpp-example.html":[5,47],
"Polygon_mesh_processing_2compute_normals_example_8cpp-example.html":[5,9],
"Polygon_mesh_processing_2compute_normals_example_Polyhedron_8cpp-example.html":[5,27],
"Polygon_mesh_processing_2connected_components_example_8cpp-example.html":[5,12],
"Polygon_mesh_processing_2corefinement_OM_union_8cpp-example.html":[5,33],
"Polygon_mesh_processing_2corefinement_consecutive_bool_op_8cpp-example.html":[5,35],
"Polygon_mesh_processing_2corefinement_difference_remeshed_8cpp-example.html":[5,30],
"Polygon_mesh_processing_2corefinement_mesh_union_8cpp-example.html":[5,31],
"Polygon_mesh_processing_2corefinement_mesh_union_and_intersection_8cpp-example.html":[5,34],
"Polygon_mesh_processing_2corefinement_mesh_union_progress_8cpp-example.html":[5,32],
"Polygon_mesh_processing_2delaunay_remeshing_example_8cpp-example.html":[5,26],
"Polygon_mesh_processing_2detect_features_example_8cpp-example.html":[5,36],
"Polygon_mesh_processing_2extrude_8cpp-example.html":[5,0],
"Polygon_mesh_processing_2face_filtered_graph_example_8cpp-example.html":[5,13],
"Polygon_mesh_processing_2hausdorff_bounded_error_distance_example_8cpp-example.html":[5,46],
"Polygon_mesh_processing_2hausdorff_distance_remeshing_example_8cpp-example.html":[5,28],
"Polygon_mesh_processing_2hole_filling_example_8cpp-example.html":[5,5],
"Polygon_mesh_processing_2hole_filling_example_SM_8cpp-example.html":[5,6],
"Polygon_mesh_processing_2hole_filling_visitor_example_8cpp-example.html":[5,7],
"Polygon_mesh_processing_2interpolated_corrected_curvatures_PH_8cpp-example.html":[5,24],
"Polygon_mesh_processing_2interpolated_corrected_curvatures_SM_8cpp-example.html":[5,23],
"Polygon_mesh_processing_2interpolated_corrected_curvatures_vertex_8cpp-example.html":[5,25],
"Polygon_mesh_processing_2isotropic_remeshing_example_8cpp-example.html":[5,18],
"Polygon_mesh_processing_2isotropic_remeshing_of_patch_example_8cpp-example.html":[5,19],
"Polygon_mesh_processing_2isotropic_remeshing_with_allow_move_8cpp-example.html":[5,20],
"Polygon_mesh_processing_2isotropic_remeshing_with_custom_sizing_example_8cpp-example.html":[5,21],
"Polygon_mesh_processing_2isotropic_remeshing_with_sizing_example_8cpp-example.html":[5,22],
"Polygon_mesh_processing_2locate_example_8cpp-example.html":[5,43],
"Polygon_mesh_processing_2manifoldness_repair_example_8cpp-example.html":[5,38],
"Polygon_mesh_processing_2mesh_slicer_example_8cpp-example.html":[5,17],
"Polygon_mesh_processing_2mesh_smoothing_example_8cpp-example.html":[5,40],
"Polygon_mesh_processing_2orient_polygon_soup_example_8cpp-example.html":[5,14],
"Polygon_mesh_processing_2orientation_pipeline_example_8cpp-example.html":[5,44],
"Polygon_mesh_processing_2point_inside_example_8cpp-example.html":[5,10],
"Polygon_mesh_processing_2polyhedral_envelope_8cpp-example.html":[5,1],
"Polygon_mesh_processing_2polyhedral_envelope_mesh_containment_8cpp-example.html":[5,3],
"Polygon_mesh_processing_2polyhedral_envelope_of_triangle_soup_8cpp-example.html":[5,2],
"Polygon_mesh_processing_2refine_fair_example_8cpp-example.html":[5,16],
"Polygon_mesh_processing_2remesh_almost_planar_patches_8cpp-example.html":[5,49],
"Polygon_mesh_processing_2remesh_planar_patches_8cpp-example.html":[5,48],
"Polygon_mesh_processing_2repair_polygon_soup_example_8cpp-example.html":[5,39],
"Polygon_mesh_processing_2sample_example_8cpp-example.html":[5,51],
"Polygon_mesh_processing_2self_intersections_example_8cpp-example.html":[5,4],
"Polygon_mesh_processing_2shape_smoothing_example_8cpp-example.html":[5,41],
"Polygon_mesh_processing_2snap_polygon_soup_8cpp-example.html":[5,53],
"Polygon_mesh_processing_2soup_autorefinement_8cpp-example.html":[5,52],
"Polygon_mesh_processing_2stitch_borders_example_8cpp-example.html":[5,8],
"Polygon_mesh_processing_2tangential_relaxation_example_8cpp-example.html":[5,42],
"Polygon_mesh_processing_2triangulate_faces_example_8cpp-example.html":[5,11],
"Polygon_mesh_processing_2triangulate_faces_split_visitor_example_8cpp-example.html":[5,45],
"Polygon_mesh_processing_2triangulate_polyline_example_8cpp-example.html":[5,15],
"Polygon_mesh_processing_2volume_connected_components_8cpp-example.html":[5,37],
"annotated.html":[4],
"citelist.html":[3],
"classCGAL_1_1Polygon__mesh__processing_1_1Adaptive__sizing__field.html":[1,0,3,0],
"classCGAL_1_1Polygon__mesh__processing_1_1Adaptive__sizing__field.html#a0fe67f0010ea57944dc5d6c17638d140":[1,0,3,0,0],
"classCGAL_1_1Polygon__mesh__processing_1_1Uniform__sizing__field.html":[1,0,3,1],
"classCGAL_1_1Polygon__mesh__processing_1_1Uniform__sizing__field.html#aa0a9fe98e7168de655888ccb87e212d7":[1,0,3,1,0],
"classCGAL_1_1Polygon__mesh__processing_1_1Uniform__sizing__field.html#af13fd54fb85fd6b86bae3a0e90cb4fa2":[1,0,3,1,1],
"classCGAL_1_1Polygon__mesh__slicer.html":[1,0,19],
"classCGAL_1_1Polygon__mesh__slicer.html#a2ccb40298bed1b68ffdad07c43f3c04e":[1,0,19,5],
"classCGAL_1_1Polygon__mesh__slicer.html#a316370a17f840d75088893b0893c87b0":[1,0,19,4],
"classCGAL_1_1Polygon__mesh__slicer.html#a6a2a410eac503ccfb636ff4f97cac74d":[1,0,19,2],
"classCGAL_1_1Polygon__mesh__slicer.html#a9ebdc037949989a04604714127d55bb5":[1,0,19,0],
"classCGAL_1_1Polygon__mesh__slicer.html#aad9b168fa99f09b4f865293842a4c3e0":[1,0,19,1],
"classCGAL_1_1Polygon__mesh__slicer.html#abd67ea7ecab1e4bdaafe490f0d8e0324":[1,0,19,3],
"classCGAL_1_1Rigid__triangle__mesh__collision__detection.html":[1,0,21],
"classCGAL_1_1Rigid__triangle__mesh__collision__detection.html#a09b027b0f7ab35e8f87f8fa793d3372e":[1,0,21,9],
"classCGAL_1_1Rigid__triangle__mesh__collision__detection.html#a0ddf5e0df0e667ea68dafcf25c66d2a6":[1,0,21,11],
"classCGAL_1_1Rigid__triangle__mesh__collision__detection.html#a0f935fc3540e3a08721353d22e395b17":[1,0,21,7],
"classCGAL_1_1Rigid__triangle__mesh__collision__detection.html#a192e27722ea5cdccb7b28c73165c0396":[1,0,21,1],
"classCGAL_1_1Rigid__triangle__mesh__collision__detection.html#a2eda001d87128694ae0d86971929f916":[1,0,21,13],
"classCGAL_1_1Rigid__triangle__mesh__collision__detection.html#a413679432bd44257f1f275059c3876a2":[1,0,21,6],
"classCGAL_1_1Rigid__triangle__mesh__collision__detection.html#a6ccb79ff847da7862e3e4e982d220234":[1,0,21,8],
"classCGAL_1_1Rigid__triangle__mesh__collision__detection.html#a893dca62b65646d0b27f480dfab150bf":[1,0,21,14],
"classCGAL_1_1Rigid__triangle__mesh__collision__detection.html#aa9b6429f923ade825b2328829aab5e45":[1,0,21,5],
"classCGAL_1_1Rigid__triangle__mesh__collision__detection.html#ab2e1ac1b74908d0eb91b3219a2836c56":[1,0,21,10],
"classCGAL_1_1Rigid__triangle__mesh__collision__detection.html#ad6a30e1ef60fa9c5b79217b4b4b0ad3c":[1,0,21,0],
"classCGAL_1_1Rigid__triangle__mesh__collision__detection.html#ae69660a332a5bd1c5274b6ddd9cddff4":[1,0,21,12],
"classCGAL_1_1Rigid__triangle__mesh__collision__detection.html#ae76e39404aca063218c1a5cc9011e212":[1,0,21,4],
"classCGAL_1_1Rigid__triangle__mesh__collision__detection.html#ae7cd885c1bf2f9259b6c609b8bb8cb94":[1,0,21,2],
"classCGAL_1_1Rigid__triangle__mesh__collision__detection.html#afe5b50df0dd0f0ca85fafec145f7823d":[1,0,21,3],
"classCGAL_1_1Side__of__triangle__mesh.html":[1,0,15,0],
"classCGAL_1_1Side__of__triangle__mesh.html#a05c896871012c2e0e86fac65db6b5912":[1,0,15,0,3],
"classCGAL_1_1Side__of__triangle__mesh.html#a0a2b740ebc8f4f7d395cef082aa2a01c":[1,0,15,0,5],
"classCGAL_1_1Side__of__triangle__mesh.html#a15c506c6ef97c1f6f9679b61c453eb29":[1,0,15,0,1],
"classCGAL_1_1Side__of__triangle__mesh.html#a2263b10214e5b5974eda87c4dd58aee7":[1,0,15,0,0],
"classCGAL_1_1Side__of__triangle__mesh.html#acaf80bc717521b07da96a865352c6b3c":[1,0,15,0,2],
"classCGAL_1_1Side__of__triangle__mesh.html#ae618cf6fa412ea74219bb7ca3760d311":[1,0,15,0,6],
"classCGAL_1_1Side__of__triangle__mesh.html#af17094431ba27a55d33d1e35ea29aef8":[1,0,15,0,4],
"classCGAL_1_1Side__of__triangle__mesh.html#af18f0a7795027cc92a372fa0d9a2710e":[1,0,15,0,7],
"classPMPAutorefinementVisitor.html":[1,0,0,0],
"classPMPAutorefinementVisitor.html#a2b7130b0c94651e21b6a3c4f2d3ec765":[1,0,0,0,2],
"classPMPAutorefinementVisitor.html#a454023769deabacd45540d8a5dcb27ab":[1,0,0,0,3],
"classPMPAutorefinementVisitor.html#ab2d0abdf3d2e9dc47640ca37f9737055":[1,0,0,0,1],
"classPMPAutorefinementVisitor.html#abb941778c6bbe1fdcd2c7fe5d89650ac":[1,0,0,0,0],
"classPMPCorefinementVisitor.html":[1,0,0,1],
"classPMPCorefinementVisitor.html#a02669432c89cfeaa2c69446afda07f1e":[1,0,0,1,32],
"classPMPCorefinementVisitor.html#a0d160a1573cd93115b300ec86c9221d8":[1,0,0,1,38],
"classPMPCorefinementVisitor.html#a0da4738da462d803465d09987d315f21":[1,0,0,1,26],
"classPMPCorefinementVisitor.html#a1276fd28e4443a9cbfa14c5d64258323":[1,0,0,1,41],
"classPMPCorefinementVisitor.html#a1bc3aa40f990e83bb6b5cd7f6ddffc42":[1,0,0,1,18],
"classPMPCorefinementVisitor.html#a1ecf573a53a439e94ff33d0619efb390":[1,0,0,1,2],
"classPMPCorefinementVisitor.html#a2a2d75da057dcdaf3232c579329ad85b":[1,0,0,1,30],
"classPMPCorefinementVisitor.html#a2c228867e23eef9b90c2826d303ca8a5":[1,0,0,1,13],
"classPMPCorefinementVisitor.html#a436717c3d86f8858edcd83eed81b733b":[1,0,0,1,21],
"classPMPCorefinementVisitor.html#a473a93975a089c19c695aeff921e8964":[1,0,0,1,35],
"classPMPCorefinementVisitor.html#a515678d067926aa9df04677a3f1df6b4":[1,0,0,1,5],
"classPMPCorefinementVisitor.html#a68525c003867c6cbf68f522d949e6a15":[1,0,0,1,16],
"classPMPCorefinementVisitor.html#a72d353688616d1746e2dd8990a4c3803":[1,0,0,1,0],
"classPMPCorefinementVisitor.html#a7bdf1b81fd005654e19fc344aa026863":[1,0,0,1,9],
"classPMPCorefinementVisitor.html#a7e109ecde7ed610a1af1c53d4d8cffe9":[1,0,0,1,22],
"classPMPCorefinementVisitor.html#a8a16fd716c8be00a13ead5c7b6656f23":[1,0,0,1,14],
"classPMPCorefinementVisitor.html#a8bc4cb77915694e7a3dc6428305323d8":[1,0,0,1,36],
"classPMPCorefinementVisitor.html#a9499eac0ae81a5a469e28c3fdc41e2b0":[1,0,0,1,42],
"classPMPCorefinementVisitor.html#a98422d4a6689cbaaef3c107a1be439c6":[1,0,0,1,34],
"classPMPCorefinementVisitor.html#a9adc3c945d5965ca82e58af5e01a0652":[1,0,0,1,7],
"classPMPCorefinementVisitor.html#a9f5a635e082e2a12dcc98baeffe7efac":[1,0,0,1,1],
"classPMPCorefinementVisitor.html#aa606ff79672e2542c1fabb4443688b8a":[1,0,0,1,4],
"classPMPCorefinementVisitor.html#aa8521c2516475ac2fe9115e381b30ff7":[1,0,0,1,29],
"classPMPCorefinementVisitor.html#aa8b47a99b7ffa3fad218015286a24fde":[1,0,0,1,24],
"classPMPCorefinementVisitor.html#aaaf8fed0acc326dcf50496d5649dcc7a":[1,0,0,1,20],
"classPMPCorefinementVisitor.html#aac745bdd3bd7f3ca4d0fd6ced6f4fca8":[1,0,0,1,15],
"classPMPCorefinementVisitor.html#aad3a4eade447e236ec993fc05cb8020e":[1,0,0,1,10],
"classPMPCorefinementVisitor.html#ab819d40a2bda062d883ac2a6fb62e8f8":[1,0,0,1,3],
"classPMPCorefinementVisitor.html#acd13f3e9b14a96191d1cc07f0014897f":[1,0,0,1,33],
"classPMPCorefinementVisitor.html#acdcad95153212809d7cb86a4e4dbacfb":[1,0,0,1,23],
"classPMPCorefinementVisitor.html#aceccd3914adea586d117b628e0fcc1e2":[1,0,0,1,11],
"classPMPCorefinementVisitor.html#ad7346675f069294e78d3425a44f09978":[1,0,0,1,28],
"classPMPCorefinementVisitor.html#ad742db01b774aed6b3edca64e5795ee3":[1,0,0,1,39],
"classPMPCorefinementVisitor.html#adc77b92dd3b34ecf38256843f732c2d7":[1,0,0,1,8],
"classPMPCorefinementVisitor.html#adcd05ea07c741b505c02902cb3b803d9":[1,0,0,1,31],
"classPMPCorefinementVisitor.html#adf3a799f88e90df66b9f44468c996bd6":[1,0,0,1,40],
"classPMPCorefinementVisitor.html#adfcee239435f91731bab7908e52c9449":[1,0,0,1,27],
"classPMPCorefinementVisitor.html#ae0d4dfeedf82a857b1910f351231443e":[1,0,0,1,17],
"classPMPCorefinementVisitor.html#ae2943fc8d6bf1b3f9c17b3b9c19c935c":[1,0,0,1,25],
"classPMPCorefinementVisitor.html#ae78af2adbbbb4d0c9b6a80a0688e6719":[1,0,0,1,12],
"classPMPCorefinementVisitor.html#af2eae8d512832aa4218af4f91a30e045":[1,0,0,1,19],
"classPMPCorefinementVisitor.html#af2f61a0a46ba27c8bc011838fc987058":[1,0,0,1,6],
"classPMPCorefinementVisitor.html#af44d93902c3e1f4afa11f7a1d12b2624":[1,0,0,1,37],
"classPMPDistanceTraits.html":[1,0,0,2],
"classPMPDistanceTraits.html#a06c263c3c5b34f1053b024b9b8f78d7d":[1,0,0,2,2],
"classPMPDistanceTraits.html#a082fe010f412a3c1d5e05221d7227ae4":[1,0,0,2,0],
"classPMPDistanceTraits.html#a0a58e2b996d696ee50a92710848398e0":[1,0,0,2,6],
"classPMPDistanceTraits.html#a704303a0d10efaa8a56a010d79346b25":[1,0,0,2,4],
"classPMPDistanceTraits.html#a9e64c7865a0e71ab722055b8c29c50f0":[1,0,0,2,5],
"classPMPDistanceTraits.html#aa94a729ff8bde9df89530b9e7bb6c722":[1,0,0,2,7],
"classPMPDistanceTraits.html#ab86db55e6f27755dacb4d9f88107a82d":[1,0,0,2,1],
"classPMPDistanceTraits.html#ace007a88453bcf18c2483e60a762859c":[1,0,0,2,3],
"classPMPHolefillingVisitor.html":[1,0,0,3],
"classPMPHolefillingVisitor.html#a144aaa0f9dc844264acbf72e6d9d85dd":[1,0,0,3,7],
"classPMPHolefillingVisitor.html#a1552fad2934c7591f671ed6c8367e95f":[1,0,0,3,2],
"classPMPHolefillingVisitor.html#a17eddb4a44998a76125154850a4f0b47":[1,0,0,3,1],
"classPMPHolefillingVisitor.html#a183d85e93f3e08405afac9dc7596285f":[1,0,0,3,8],
"classPMPHolefillingVisitor.html#a5ba69027a93b3c8b9b45111d37a7fed0":[1,0,0,3,3],
"classPMPHolefillingVisitor.html#ab187c68ddb03eb66945d1ad26947fc8b":[1,0,0,3,4],
"classPMPHolefillingVisitor.html#ad6ca046de37798640b58cdf3c626313f":[1,0,0,3,10],
"classPMPHolefillingVisitor.html#ad76ba26af056009bd312c9fc26b25ff0":[1,0,0,3,9],
"classPMPHolefillingVisitor.html#ad7d6765bce9c4a81435cd328a15c2ca1":[1,0,0,3,0],
"classPMPHolefillingVisitor.html#ae1034b2fa9bfb7391d2733aecbee95c5":[1,0,0,3,5],
"classPMPHolefillingVisitor.html#af44dc7491edfd311b8fa08afb0d82aa2":[1,0,0,3,11],
"classPMPHolefillingVisitor.html#af85b6274f2a0a7a77cc657e8f80bd9c5":[1,0,0,3,6],
"classPMPPolygonSoupOrientationVisitor.html":[1,0,0,4],
"classPMPPolygonSoupOrientationVisitor.html#a20deb5b24a3db638d29fb85810b53c5d":[1,0,0,4,4],
"classPMPPolygonSoupOrientationVisitor.html#a37e165c1ca3ae40cfc45c507336168fe":[1,0,0,4,3],
"classPMPPolygonSoupOrientationVisitor.html#a62f72578956f0c5c90c7a898b59814b3":[1,0,0,4,5],
"classPMPPolygonSoupOrientationVisitor.html#a8b5c0fe1538a5cc4c3c2c73aa10f5e29":[1,0,0,4,0],
"classPMPPolygonSoupOrientationVisitor.html#a9937ae45797a68f4df72810fe903a434":[1,0,0,4,1],
"classPMPPolygonSoupOrientationVisitor.html#ae343638a6011f52d23b472f602d49307":[1,0,0,4,2],
"classPMPSelfIntersectionTraits.html":[1,0,0,5],
"classPMPSelfIntersectionTraits.html#a0cd254de374b3b52dfa55268c99de276":[1,0,0,5,2],
"classPMPSelfIntersectionTraits.html#a66f3a6d91df8b9708695119b8d588003":[1,0,0,5,4],
"classPMPSelfIntersectionTraits.html#a841af4ea980b4130a4fa477633bc4dcf":[1,0,0,5,1],
"classPMPSelfIntersectionTraits.html#adbd168594bb0dda280073cd886bcae5e":[1,0,0,5,3],
"classPMPSelfIntersectionTraits.html#ae490aafcda8ed998759842a67a57ca92":[1,0,0,5,0],
"classPMPSelfIntersectionTraits.html#aec3c2d71b0d0197f7b991cf45954a6c5":[1,0,0,5,5],
"classPMPSizingField.html":[1,0,0,6],
"classPMPSizingField.html#a0a0ee7e5a2c3bc442a9350a02b1b2f24":[1,0,0,6,4],
"classPMPSizingField.html#a42a21767d6e96fc6645edf1c6d312d1c":[1,0,0,6,8],
"classPMPSizingField.html#a557a97827ef40f6d6fb866a1a749e6ab":[1,0,0,6,2],
"classPMPSizingField.html#a70cc54d401f84a313ebc54d957fd247a":[1,0,0,6,6],
"classPMPSizingField.html#a760182d3f098d5c709c7e47a9653acf0":[1,0,0,6,9],
"classPMPSizingField.html#a998f26cbc6ac3edbfa4703847ef03dd1":[1,0,0,6,5],
"classPMPSizingField.html#aaf135545d27f1352b59e872cc6500ac8":[1,0,0,6,7],
"classPMPSizingField.html#ac91844c2049943895fbcb1e6017be89c":[1,0,0,6,3],
"classPMPSizingField.html#acb8d0afb2a0acec38cbfd1741b5dcc98":[1,0,0,6,1],
"classPMPSizingField.html#af2b8137aed4d180e0b4f4a283999ee2d":[1,0,0,6,0],
"classPMPTriangulateFaceVisitor.html":[1,0,0,7],
"classPMPTriangulateFaceVisitor.html#a25b9d941ff6faaa36bcf2031ff0ae14a":[1,0,0,7,0],
"classPMPTriangulateFaceVisitor.html#a639708124560683968cbe9e7c5f5dd13":[1,0,0,7,2],
"classPMPTriangulateFaceVisitor.html#a709576ece4862f7a9ae3d3a80e865211":[1,0,0,7,1],
"classPMPTriangulateFaceVisitor.html#a90682678607fc5d677b505868ace6068":[1,0,0,7,3],
"deprecated.html":[2],
"examples.html":[5],
"group__PMPDeprecated.html":[1,0,17],
"group__PMPDeprecated.html#ga79c2b4ad31e2dd15b93725e8efd5208a":[1,0,17,0],
"group__PMP__IO__grp.html":[1,0,16],
"group__PMP__IO__grp.html#gac5b3295bd1b6375628a46d1fbaf7e881":[1,0,16,0],
"group__PMP__combinatorial__repair__grp.html":[1,0,9],
"group__PMP__combinatorial__repair__grp.html#ga121f588ac324938d9a6b6931a08661e1":[1,0,9,1],
"group__PMP__combinatorial__repair__grp.html#ga152989d1d1edabb9f68296d9395eb2dd":[1,0,9,13],
"group__PMP__combinatorial__repair__grp.html#ga1f215926ed8794db827e2993d2960870":[1,0,9,3],
"group__PMP__combinatorial__repair__grp.html#ga25901cbedcc6123d7760ac5b9dc8d14e":[1,0,9,0],
"group__PMP__combinatorial__repair__grp.html#ga2af4c26afc4872bafd0caabe6af23f9a":[1,0,9,6],
"group__PMP__combinatorial__repair__grp.html#ga2ba9722ec8472a1455107ffce7145e46":[1,0,9,9],
"group__PMP__combinatorial__repair__grp.html#ga31bf16dbfb6e46202ca4277df8e69908":[1,0,9,15],
"group__PMP__combinatorial__repair__grp.html#ga36098d2415efd0604b7b996163bc22db":[1,0,9,7],
"group__PMP__combinatorial__repair__grp.html#ga3b35133783759402828325b91ab559cc":[1,0,9,11],
"group__PMP__combinatorial__repair__grp.html#ga3be94f1f7968022a294dd533400ad554":[1,0,9,8],
"group__PMP__combinatorial__repair__grp.html#ga562d3f935e55a6378d407183f9533dd1":[1,0,9,12],
"group__PMP__combinatorial__repair__grp.html#ga621eebea618dc7d2356fa7fddb026905":[1,0,9,16],
"group__PMP__combinatorial__repair__grp.html#ga740c417af0ef24a16faebb23727d089c":[1,0,9,14],
"group__PMP__combinatorial__repair__grp.html#ga8b9d12d817b5cc76f5a42d74eac75bf3":[1,0,9,2],
"group__PMP__combinatorial__repair__grp.html#ga93d14c26c259b5844dbd5a7753278e5f":[1,0,9,4],
"group__PMP__combinatorial__repair__grp.html#ga95ff13c1578f509fa8ed58b1884d0e46":[1,0,9,5],
"group__PMP__combinatorial__repair__grp.html#gaef5c13fc9dd4cae14c860351c479a45f":[1,0,9,10],
"group__PMP__corefinement__grp.html":[1,0,12],
"group__PMP__corefinement__grp.html#ga02fa6ed9116a759ecfb87063392f5455":[1,0,12,11],
"group__PMP__corefinement__grp.html#ga0c49ffd458b13ee9489cad2321656f71":[1,0,12,16],
"group__PMP__corefinement__grp.html#ga2c73d3460872e601f84a03f58dd069ae":[1,0,12,6],
"group__PMP__corefinement__grp.html#ga3be2ae4b7de3a1d9288f7febfc27eb9a":[1,0,12,3],
"group__PMP__corefinement__grp.html#ga3e3a0a82b6c04bdc3a6c070e8da4aed5":[1,0,12,4],
"group__PMP__corefinement__grp.html#ga3ff96d36cad8f37efcdada916c46fbbe":[1,0,12,12],
"group__PMP__corefinement__grp.html#ga54baccf4fbd1b1ada67465ec1d4bddc1":[1,0,12,9],
"group__PMP__corefinement__grp.html#ga5dc9e7acf8433235adc7b91ac93a7d42":[1,0,12,8],
"group__PMP__corefinement__grp.html#ga642520055888a41a3e1a76965a1f9fbb":[1,0,12,17],
"group__PMP__corefinement__grp.html#ga6738052411a4d548a5b375f11b913924":[1,0,12,15],
"group__PMP__corefinement__grp.html#ga6e6c4a724ce19e7a207de56f3a7408ab":[1,0,12,18],
"group__PMP__corefinement__grp.html#ga95f618914f8d54d840065204b029492f":[1,0,12,13],
"group__PMP__corefinement__grp.html#gaafa5e46c35c3fef461a47d73b4566961":[1,0,12,10],
"group__PMP__corefinement__grp.html#gacb9d68fa4dea8fd03ec53b56a16d6fc6":[1,0,12,14],
"group__PMP__corefinement__grp.html#gad934517ebf9a6427e52d457ed24faf79":[1,0,12,7],
"group__PMP__corefinement__grp.html#gaf7747d676c459d9e5da9b13be7d12bb5":[1,0,12,5],
"group__PMP__corrected__curvatures__grp.html":[1,0,4],
"group__PMP__corrected__curvatures__grp.html#ga22665c9ce92aaedab07df1b05f20bdb2":[1,0,4,1],
"group__PMP__corrected__curvatures__grp.html#ga78329aab7b2fcd86880fd79dd36bd55b":[1,0,4,2],
"group__PMP__detect__features__grp.html":[1,0,13],
"group__PMP__detect__features__grp.html#ga68042f21c5cafe94d316c4b1fe7c9aed":[1,0,13,1],
"group__PMP__detect__features__grp.html#gad9cf9f1c459540156fb235a487bebd01":[1,0,13,2],
"group__PMP__detect__features__grp.html#gadd3d18c0a9773463cd57902f85d0b23d":[1,0,13,0],
"group__PMP__distance__grp.html":[1,0,11],
"group__PMP__distance__grp.html#ga035fdbf660615b036cb3f47f7997b739":[1,0,11,2],
"group__PMP__distance__grp.html#ga276e117793ebf6abbb3629423ad700e9":[1,0,11,8],
"group__PMP__distance__grp.html#ga3451246234c24dd4f03d17fc17d50336":[1,0,11,1],
"group__PMP__distance__grp.html#ga6307a4504382c46dc3b0e578ca1f7a3b":[1,0,11,7],
"group__PMP__distance__grp.html#ga74376aa81d44d745426acfad5a0ac8de":[1,0,11,0],
"group__PMP__distance__grp.html#gac251a5e983df7ee6aa61623cdb9ec454":[1,0,11,3],
"group__PMP__distance__grp.html#gacd7487071c9d409e91c37a731999a239":[1,0,11,5]
};
